<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'SINGLE_Settings:Webforms'     => 'Webform'                     , // TODO: Review
	'WebForm Name'                 => 'Webform Name'                , // TODO: Review
	'Public Id'                    => 'Public Id'                   , // TODO: Review
	'Enabled'                      => 'Status'                      , // TODO: Review
	'Module'                       => 'Module'                      , // TODO: Review
	'Return Url'                   => 'Return Url'                  , // TODO: Review
	'Post Url'                     => 'Post Url'                    , // TODO: Review
    'Captcha Enabled'              => 'Captcha ingeschakeld'        ,
	'SINGLE_Webforms'              => 'Webform'                     , // TODO: Review
	'LBL_SHOW_FORM'                => 'Show Form'                   , // TODO: Review
	'LBL_DUPLICATES_EXIST'         => 'Webform Name already exists' , // TODO: Review
	'LBL_WEBFORM_INFORMATION'      => 'Webform Information'         , // TODO: Review
	'LBL_FIELD_INFORMATION'        => 'Field Information'           , // TODO: Review
	'LBL_FIELD_NAME'               => 'Field Name'                  , // TODO: Review
	'LBL_OVERRIDE_VALUE'           => 'Override Value'              , // TODO: Review
	'LBL_MANDATORY'                => 'Mandatory'                   , // TODO: Review
	'LBL_WEBFORM_REFERENCE_FIELD'  => 'Webforms reference Field'    , // TODO: Review
	'LBL_SELECT_FIELDS_OF_TARGET_MODULE' => 'Select Fields for Target Module...', // TODO: Review
	'LBL_ALLOWS_YOU_TO_MANAGE_WEBFORMS' => 'Allows you to manage webforms', // TODO: Review
	'LBL_ADD_FIELDS'               => 'Add Fields'                  , // TODO: Review
	'LBL_EMBED_THE_FOLLOWING_FORM_IN_YOUR_WEBSITE' => 'Embed the following form in your website', // TODO: Review
	'LBL_SELECT_VALUE'             => 'Select Value'                , // TODO: Review
	'LBL_LABEL'                    => 'label'                       , // TODO: Review
	'LBL_SAVE_FIELDS_ORDER' => 'Sparen velden bestellen', 
	'LBL_HIDDEN' => 'Verborgen',
	'LBL_ENABLE_TARGET_MODULES_FOR_WEBFORM' => 'Enable Target modules voor webformulier',
	'LBL_ASSIGN_USERS' => 'Gebruiker Assignment',
    'LBL_ASSIGN_ROUND_ROBIN' => 'Gebruikers toewijzen In Round Robin',
    'LBL_ROUNDROBIN_USERS_LIST' => 'Round Robin Gebruikers Lijst',

  'LBL_ADD_RECORD' => 'Toevoegen Webformulier',

	'LBL_UPLOAD_DOCUMENTS' => 'Upload Documents',
	'LBL_ADD_FILE_FIELD' => 'Bestanden uploaden Field',
	'LBL_FIELD_LABEL' => 'Document titel',
	'LBL_FILE_FIELD_INFO' => 'Voor elk bestand geüpload van web vormen een nieuw document wordt gemaakt met het bijgevoegde bestand. Het document is ook gekoppeld aan deze nieuw gecreëerde%s.',
	'LBL_NO_FILE_FIELD' => 'Geen bestand velden toegevoegd.',
	'LBL_COPY_TO_CLIPBOARD' => 'Kopieer naar klembord',
);
$jsLanguageStrings = array(
	'JS_WEBFORM_DELETED_SUCCESSFULLY' => 'Webform deleted successfully', // TODO: Review
	'JS_LOADING_TARGET_MODULE_FIELDS' => 'Loadding Target Module Fields', // TODO: Review
	'JS_SELECT_VALUE'              => 'Select Vlaue'                , // TODO: Review
	'JS_MANDATORY_FIELDS_WITHOUT_OVERRIDE_VALUE_CANT_BE_HIDDEN' => 'Verplichte velden zonder voorrang boven de waarden niet kan worden verborgen',
	'JS_REFERENCE_FIELDS_CANT_BE_MANDATORY_WITHOUT_OVERRIDE_VALUE' => 'Referentievelden cant verplicht zijn zonder override waarde',
	'JS_TYPE_TO_SEARCH' => 'Typ om te zoeken',
	"JS_WEBFORM_WITH_THIS_NAME_ALREADY_EXISTS" => 'Webformulier met deze naam bestaat',

  'JS_SELECT_AN_OPTION' => 'Selecteer een Optie',
  'JS_LABEL' => 'label',

	'JS_MAX_FILE_FIELDS_LIMIT' => 'Maximaal kun je%s bestand velden toe te voegen.',
	'JS_COPIED_SUCCESSFULLY' => 'gekopieerd.',
	'JS_COPY_FAILED' => 'Kopiëren mislukt. Gelieve handmatig te kopiëren.',
);